# 2021-06-24 - Stable Pool

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This factory and associated Pools have been deprecated due to numerical issues when one of the token depegs. It was superseded by an [updated version (also now deprecated)](../20220609-stable-pool-v2).

Deployment of the `StablePoolFactory`, for Stable Pools of up to 5 tokens.

## Useful Files

- [Ethereum mainnet address](./output/mainnet.json)
- [Polygon mainnet address](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [Optimism mainnet address](./output/optimism.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`StablePoolFactory` artifact](./artifact/StablePoolFactory.json)
